# Filename   : vid2su.rb
# Date       : 2008/04/28
# Name       : Burkhard Bals' Plugin
# Description: Sets up the UI and so on.
#              This file is meant not to be loaded separately.
# Author     : Mario Pehle, www.errorinitus.de
# Version    : 2008/04/28 - 1.0: created this file (mp)
#            : 2008/05/01 - 2.0: corrected WebDialog initialization (mp)


begin
  
  unless file_loaded? __FILE__
    
    module BB
      
      
      class MainWindow < UI::WebDialog
        
        private
          
          def initialize
            super(
              BB::PLUGIN_NAME,
              true,
              nil,
              BB::WINDOW_WIDTH,
              BB::WINDOW_HEIGHT,
              BB::WINDOW_X,
              BB::WINDOW_Y,
              true
            )
            set_size BB::WINDOW_WIDTH, BB::WINDOW_HEIGHT
            set_url BB::HOME_URL
          end
          
      end
      
      
      class AboutWindow < UI::WebDialog
        
        private
          
          def get_html
            File.readlines("#{File.dirname(__FILE__)}/" +

              BB::ABOUT_FILE_NAME).join.sub(
                Regexp.new("<!-- VERSION //-->"), BB::VERSION
            )
          end
          
          def initialize
            super "About #{BB::PLUGIN_NAME} ...", false, nil, 640, 480, 10, 10, true
            set_size 240, 360
            set_html get_html
          end
          
      end
      
      
      class UserInterface
        
        private
          
          def items
            [
              {
                :menu            => true,
                :toolbar         => true,
                :toolbar_icon_s  => BB::ICON_SMALL,
                :toolbar_icon_l  => BB::ICON_LARGE,
                :toolbar_tooltip => 'Show, Home',
                :status_bar_text => 'Show, Home',
                :menu_text       => 'Show, Home',
                :name            => 'Show, Home',
                :validation      => Proc.new do
                  Sketchup.is_online ? MF_ENABLED : MF_GRAYED
                end,
                :action          => Proc.new do
                  @main_window.show unless @main_window.visible?
                  @main_window.bring_to_front
                  @main_window.set_url BB::HOME_URL
                end
              },
              {
                :name    => :separator,
                :menu    => true,
                :toolbar => false
              },
              {
                :menu            => true,
                :toolbar         => false,
                :status_bar_text => 'About ...',
                :menu_text       => 'About ...',
                :name            => 'About ...',
                :action          => Proc.new do
                  @about_window.show unless @about_window.visible?
                  @about_window.bring_to_front
                end
              }
            ]
          end
          
          def initialize
            @setup        = false
            @menu         = nil
            @items        = items
            @toolbar      = nil
            @main_window  = MainWindow.new
            @about_window = AboutWindow.new
            self
          end
          
          def setup_menu
            @menu = UI.menu(BB::BASE_MENU_NAME).add_submenu(BB::PLUGIN_NAME)
            for a in @items do
              if a[:menu]
                if a[:name] == :separator
                  @menu.add_separator
                  next
                end
                item = @menu.add_item(a[:name], &a[:action])
                @menu.set_validation_proc(item, &a[:validation]) if a[:validation]
              end
            end
          end
          
          def setup_toolbar
            @toolbar = UI::Toolbar.new(BB::PLUGIN_NAME)
            for a in @items do
              if a[:toolbar]
                if a[:name] == :separator
                  @toolbar.add_separator
                  next
                end
                cmd = UI::Command.new(a[:name], &a[:action])
                cmd.small_icon      = a[:toolbar_icon_s]  if a[:toolbar_icon_s]
                cmd.large_icon      = a[:toolbar_icon_l]  if a[:toolbar_icon_l]
                cmd.tooltip         = a[:toolbar_tooltip] if a[:toolbar_tooltip]
                cmd.status_bar_text = a[:status_bar_text] if a[:status_bar_text]
                cmd.menu_text       = a[:menu_text]       if a[:menu_text]
                cmd.set_validation_proc(&a[:validation])  if a[:validation]
                @toolbar.add_item cmd
              end
            end
            case @toolbar.get_last_state
              when 1
                @toolbar.restore
              when -1
                @toolbar.show
            end
          end
          
        public
          
          def setup
            unless @setup
              setup_menu
              setup_toolbar
              @setup = true
            end
          end
          
      end
      
      
    end
    
    BB::UserInterface.new.setup
    
  end
  
  
rescue => e
  UI.messagebox(
    "Error\nClass: #{e.class}\nMessage: #{e.message}\n\nBacktrace:\n#{e.backtrace.join("\n")}",
    MB_MULTILINE,
    "#{BB::PLUGIN_NAME}: An error occured"
  )
end
